@@ -21,7 +21,7 @@ class DjvueSimpleRouter(SimpleRouter):
             routes.append(Route(
                 url=r'^{prefix}/djvue/footer{trailing_slash}$',
                 mapping={
-                    'get': 'get_footer',
+                    'get': 'get_footer_config',
                 },
                 name='{basename}-get_footer',
                 detail=False,
